@@ -17,7 +17,7 @@
 # along with Curphoo; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-# $Id: cmdhelp.py,v 1.3 2005/11/27 20:52:46 mkennedy Exp $
+# $Id: cmdhelp.py,v 1.4 2006/08/09 17:55:00 BoW4IamTheBOFH Exp $
 
 
 join = """/join or /j
@@ -370,6 +370,15 @@ syntax: /regex <regex>
   where <regex> is the regex filter.
 example: /regex \w{1,}@hotmail\.com """
 
+uidregex = """/uidregex
+
+	will add the regex to the regex uidignore list
+
+syntax: /uidregex <regex>
+  where <regex> is the regex filter.
+example: /uidregex \w{1,}@hotmail\.com """
+
+
 command = """ ~/.curphoo/commands
 
 	The 'command' file is where you add custom emotes, shell commands and blocks of text you find youreself repeating over and over. You can use the /load command to instantly load the changes you have made to this file... the following is an example of how to build a custom 'command' file:
@@ -529,6 +538,7 @@ help = """Curphoo Commands Help File -- (c) 2002 Alex Mercader <the_cpu_fan>
 /back                               -- tell everyone you're back
 /goto <user>                        -- follow a user into another room
 /regex <regex>                      -- ignore lines with regex
+/uidregex <regex>                   -- ignore users with regex in username
 ! <sh command>                      -- show all you've got sh fu
 !! <sh command>                     -- show yourself your sh fu
 :<message>                          -- emotes
@@ -603,6 +613,8 @@ helpd = {
 	'/pm': pm,
 	'pm': pm,
 	'/regex': regex,
-	'regex' : regex
+	'regex' : regex,
+	'/uidregex': uidregex,
+	'uidregex' : uidregex
 }
 
