@@ -17,7 +17,7 @@
 # along with Curphoo; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-# $Id: cmdparser.py,v 1.10 2006/02/10 09:12:14 mkennedy Exp $
+# $Id: cmdparser.py,v 1.14 2006/08/14 18:02:25 BoW4IamTheBOFH Exp $
 ##
 
 
@@ -38,7 +38,7 @@ AWAY_MSG = "JuGgLiNg"
 
 # I will be kicking ass if adhoc releases cause our users confusion (matt)
 
-PLUG_MSG = "is using Curphoo 0.4.2 http://savannah.nongnu.org/projects/curphoo/"
+PLUG_MSG = "is using Curphoo 0.4.3 http://savannah.nongnu.org/projects/curphoo/"
 
 def btk(cli, sess, statusbar):
 	if sess.afk:
@@ -148,6 +148,22 @@ def do(cmd, cli, sess, chatwin, statusbar):
 	elif re.match('^/r(e|egex)? *$', cmd, re.I):
 		output.list_regex(chatwin, sess, sess.myregex, sess.color['ignorelist'], 'List of regex ignores.')
 
+	# LIST ALL UIDREGEXES ON IGNORE
+	elif re.match('^/uidr(e|egex)? *$', cmd, re.I):
+		output.list_uidregex(chatwin, sess, sess.uidregex, sess.color['ignorelist'], 'List of uidregex ignores.')
+
+	# APPEND A REGEX TO THE LIST
+	elif re.match('^/uidr(e|egex)? +[^ ].*', cmd, re.I):
+		uidregex = cmd.split(' ',1).pop().strip()
+		if uidregex in sess.uidregex:
+			#output.ignore_notice(chatwin, "RegEx "+regex, sess.color['ignoreoffnotice'], 0)
+			output.ignore_notice(chatwin, sess, "UiDRegEx "+uidregex, 0)
+			sess.uidregex.remove(uidregex)
+		else:
+			#output.ignore_notice(chatwin, "RegEx "+regex, sess.color['ignoreonnotice'])
+			output.ignore_notice(chatwin, sess, "UiDRegEx "+uidregex, 1)
+			sess.uidregex.append(uidregex)
+
 	# APPEND A REGEX TO THE LIST
 	elif re.match('^/r(e|egex)? +[^ ].*', cmd, re.I):
 		regex = cmd.split(' ',1).pop().strip()
@@ -281,6 +297,14 @@ def do(cmd, cli, sess, chatwin, statusbar):
 	elif re.search('^/h(ilight-string|s) *$', cmd, re.I):
 		output.list_highliststring(chatwin, sess.highstr, sess.color['hslist'], 'List of strings to highlight')
 
+	# LIST ALL USERS ON IGNORE
+	elif re.match('^/i(g|gnore)? *$', cmd, re.I):
+		ignores = []  # ignored users in current room
+		for user in sess.users:
+			if sess.ignores.has_key(user):
+				ignores.append(user)
+		output.list_ignoredusers(chatwin, sess, ignores, sess.color['ignorelist'], 'List of users on ignore')
+
 	# QUIETLY IGNORE ANNOYING CHATTERS
 	elif re.match('^/i(g|gnore)? +[^ ].*', cmd, re.I):
 		user = cmd.split(' ',1).pop().strip()
@@ -323,13 +347,6 @@ def do(cmd, cli, sess, chatwin, statusbar):
 			output.mycomment(chatwin, sess, text=iggy_comment)
 		output.status(statusbar, sess)
 
-	# LIST ALL USERS ON IGNORE
-	elif re.match('^/i(g|gnore)? *$', cmd, re.I):
-		ignores = []  # ignored users in current room
-		for user in sess.users:
-			if sess.ignores.has_key(user):
-				ignores.append(user)
-		output.list_ignoredusers(chatwin, sess, ignores, sess.color['ignorelist'], 'List of users on ignore')
 
 	# MUTE USER - temporarily ignore a user for the duration of current session
 	elif re.match('^/mute +[^ ].*', cmd, re.I):
@@ -343,20 +360,24 @@ def do(cmd, cli, sess, chatwin, statusbar):
 		output.status(statusbar, sess)
 
 	# SHOW EXCLUDE LIST
-	elif re.match('^/(ex|exclude) +', cmd, re.I):
+	elif re.match('^/(ex|exclude)? *$', cmd, re.I):
+		excludes = []
+		for user in sess.excludes:
+			if sess.excludes.has_key(user):
+				excludes.append(user)
 		output.list_excludeusers(chatwin, sess, excludes, sess.color['excludelist'], 'List of users on excluded from auto-ignore')
 
 	# HANDLE EXCLUDE COMMAND
 	elif re.match('^/(ex|exclude) +[^ ].*', cmd, re.I):
 		user = cmd.split(' ',1).pop().strip()
-		if user in sess.excludes:
-			del sess.exclude[user]
+		if sess.excludes.has_key(user):
+			del sess.excludes[user]
 			output.exclude_notice(chatwin, sess, user, 0)
 		else:
-			sess.exclude[user] = 1
+			sess.excludes[user] = 1
 			output.exclude_notice(chatwin, sess, user)
 		output.status(statusbar, sess)
-
+		
 	# SHOW SETTINGS
 	elif re.match('^/se(t)?$', cmd, re.I):
 		output.list_rc(chatwin, sess)
@@ -492,7 +513,7 @@ def do(cmd, cli, sess, chatwin, statusbar):
 			sess.load_mycmd();
 			output.notify(chatwin, sess, 'command list loaded')
 		if param.lower() == 'exclude' or param.lower() == 'excludes':
-			sess.load_exclude();
+			sess.load_excludes();
 			output.notify(chatwin, sess, 'exclude list loaded')
 		if param.lower() == 'ignore':
 			sess.load_ignores();
@@ -506,6 +527,9 @@ def do(cmd, cli, sess, chatwin, statusbar):
 		if param.lower() == 'regex':
 			sess.load_myregex();
 			output.notify(chatwin, sess, 'regex ignore file loaded')
+		if param.lower() == 'uidregex':
+			sess.load_uidregex();
+			output.notify(chatwin, sess, 'uid regex ignore file loaded')
 
 	elif re.match(r'^/save +?[^ ].*$', cmd, re.I):
 		param = cmd.split(' ',1).pop().strip()
@@ -513,7 +537,7 @@ def do(cmd, cli, sess, chatwin, statusbar):
 			sess.save_color();
 			output.notify(chatwin, sess, 'color profile saved')
 		if param.lower() == 'exclude' or param.lower() == 'excludes':
-			sess.save_exclude();
+			sess.save_excludes();
 			output.notify(chatwin, sess, 'exclude list saved')
 		if param.lower() == 'ignore' or param.lower() == 'ignores':
 			sess.save_ignores();
@@ -524,6 +548,10 @@ def do(cmd, cli, sess, chatwin, statusbar):
 		if param.lower() == 'regex':
 			sess.save_myregex();
 			output.notify(chatwin, sess, 'regex ignore file saved')
+		if param.lower() == 'uidregex':
+			sess.save_uidregex();
+			output.notify(chatwin, sess, 'uidregex ignore file saved')
+
 
    	# *sl4ckw4re_syst3m slack@hackermail.com w0z h3r3* automagicl337sp33k 
 	elif re.match(r'^/h(a)?x(or)? +[^ ].*$', cmd, re.I):
