@@ -17,7 +17,7 @@
 # along with Curphoo; if not, write to the Free Software Foundation,
 # Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 #
-# $Id: driver.py,v 1.6 2005/11/28 04:07:28 mkennedy Exp $
+# $Id: driver.py,v 1.8 2006/08/14 19:51:04 BoW4IamTheBOFH Exp $
 
 import sys
 import curses
@@ -225,10 +225,19 @@ def hook(msg):
 
 		if not msg['text']:
 			msg['type'] = 'crap'
+
 		else:
 			try:
+				for r in sess.excludes:
+					if re.search(r, msg['user'], re.I):
+						msg['type'] = 'comment'
+						break
 				for e in sess.myregex:
-					if re.search(e, msg['text'], re.I):
+					if re.search(e, msg['text'], re.I) or re.search(e, msg['user'], re.I):
+						msg['type'] = 'crap'
+						break
+				for u in sess.uidregex:
+					if re.search(u, msg['user'], re.I):
 						msg['type'] = 'crap'
 						break
 			except:
@@ -238,6 +247,11 @@ def hook(msg):
 		user = msg['user']
 		if sess.ignores.has_key(user) or sess.mutes.has_key(user):
 			msg['type'] = 'crap'
+		for r in sess.excludes:
+			if re.search(r, msg['user'], re.I):
+				msg['type'] = 'comment'
+				break
+
 		else:
 			if msg.has_key('text') and msg['text']:
 				if not sess.userinfo.has_key(user):
@@ -256,10 +270,12 @@ def hook(msg):
 				sess.userinfo[user]['lastcomment'] = msg['text']
 				x = re.search(r'(http://|ftp://|www)[^ ]+ ?', msg['text'])
 				if x: sess.url = x.group()
+#		if sess.uidregex.re.search(user):
+#			msg['type'] = 'crap'
 	
 	# a quick hack to prevent 'crap' from seaping into output
 	if msg['type'] != 'crap':
-	#	autoignore(sess, msg)
+		autoignore(sess, msg)
 		output.message(chatwin, msg, sess.user, sess)
 		output.log(msg, sess.log)
 
