@@ -17,7 +17,7 @@
 # along with Curphoo; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-# $Id: output.py,v 1.3 2005/11/27 20:52:46 mkennedy Exp $
+# $Id: output.py,v 1.5 2006/08/14 16:48:18 BoW4IamTheBOFH Exp $
 
 import curses
 import time
@@ -109,6 +109,9 @@ def list_buddies(win, sess, ul, color, header=''):
 def list_ignoredusers(win, sess, ul, color, header=''):
 	show_list(win, sess, ul, color, header)
 
+def list_uidregex(win, sess, ul, color, header=''):
+	show_list(win, sess, ul, color, header)
+
 def list_regex(win, sess, ul, color, header=''):
 	show_list(win, sess, ul, color, header)
 
@@ -118,7 +121,7 @@ def list_excludeusers(win, sess, ul, color, header=''):
 def show_list(win, sess, ul, color, header=''):
 	win.addstr('%s (%s):' % (header, len(ul)), curses.color_pair(color)|curses.A_BOLD)
 	take_nl(win)
-	ul.sort(cmpfunc)
+#	ul.sort(cmpfunc)
 	cols = (curses.COLS - 1) / 20 
 	rows = len(ul) / cols
 	if len(ul) % cols > 0:
